@@ -2,7 +2,8 @@ import re
 
 from django.conf import settings
 from django.contrib import messages
-from django.http import HttpResponseForbidden, HttpResponseRedirect
+from django.contrib.auth.views import redirect_to_login
+from django.http import HttpResponseForbidden
 from django.utils.translation import ugettext_lazy as _
 
 # Python 2/3 compatibility hackery
@@ -12,9 +13,15 @@ except NameError:
     unicode = str
 
 
-EXEMPT_URLS = [re.compile('^%s$' % settings.LOGIN_URL.lstrip('/')), re.compile('^%s$' % settings.LOGOUT_URL.lstrip('/'))]
-EXEMPT_URLS += [re.compile(unicode(expr)) for expr in getattr(settings, 'LOGIN_EXEMPT_URLS', [])]
-PROTECTED_URLS = [re.compile(unicode(expr)) for expr in getattr(settings, 'LOGIN_PROTECTED_URLS', [r'^'])]
+LOGIN_EXEMPT_URLS = getattr(settings, 'LOGIN_EXEMPT_URLS', [])
+LOGIN_PROTECTED_URLS = getattr(settings, 'LOGIN_PROTECTED_URLS', [r'^'])
+
+EXEMPT_URLS = [
+    re.compile('^%s$' % settings.LOGIN_URL.lstrip('/')),
+    re.compile('^%s$' % settings.LOGOUT_URL.lstrip('/')),
+]
+EXEMPT_URLS += [re.compile(unicode(expr)) for expr in LOGIN_EXEMPT_URLS]
+PROTECTED_URLS = [re.compile(unicode(expr)) for expr in LOGIN_PROTECTED_URLS]
 SEND_MESSAGE = getattr(settings, 'LOGIN_REQUIRED_SEND_MESSAGE', True)
 
 
@@ -39,12 +46,14 @@ class LoginRequiredMiddleware:
     password protect instead of protecting everything under /.
     '''
     def process_request(self, request):
-        assert hasattr(request, 'user'), ("The Login Required middleware "
-            "requires authentication middleware to be installed. Edit your "
-            "MIDDLEWARE_CLASSES setting to insert "
-            "django.contrib.auth.middlware.AuthenticationMiddleware"
-            "If that doesn't work, ensure your TEMPLATE_CONTEXT_PROCESSORS "
-            "setting includes 'django.core.context_processors.auth'.")
+        assert hasattr(request, 'user'), (
+            "The 'LoginRequiredMiddleware' "
+            + "requires authentication middleware to be installed. Edit your "
+            + "'MIDDLEWARE_CLASSES' setting to insert "
+            + "'django.contrib.auth.middlware.AuthenticationMiddleware'. "
+            + "If that doesn't work, ensure your 'TEMPLATE_CONTEXT_PROCESSORS' "
+            + "setting includes 'django.core.context_processors.auth'."
+        )
 
         # Jump over this middleware if not a protected url.
         path = request.path_info.lstrip('/')
@@ -64,4 +73,5 @@ class LoginRequiredMiddleware:
         # Add a message, and redirect to login.
         if SEND_MESSAGE:
             messages.info(request, _('You must be logged in to view this page.'))
-        return HttpResponseRedirect(settings.LOGIN_URL + '?next=' + request.path_info)
+
+        return redirect_to_login(request.path_info)
